import { Prop, Provide, Emit, Model } from 'vue-property-decorator';
import { Subject, Subscription } from 'rxjs';
import { Watch, GridControlBase } from '@/studio-core';
import EAMPlanService from '@/service/eamplan/eamplan-service';
import GRID_001Service from './grid-001-grid-service';
import EAMPlanUIService from '@/uiservice/eamplan/eamplan-ui-service';
import { FormItemModel } from '@/model/form-detail';


/**
 * grid部件基类
 *
 * @export
 * @class GridControlBase
 * @extends {GRID_001GridBase}
 */
export class GRID_001GridBase extends GridControlBase {

    /**
     * 获取部件类型
     *
     * @protected
     * @type {string}
     * @memberof GRID_001GridBase
     */
    protected controlType: string = 'GRID';

    /**
     * 建构部件服务对象
     *
     * @type {GRID_001Service}
     * @memberof GRID_001GridBase
     */
    public service: GRID_001Service = new GRID_001Service({ $store: this.$store });

    /**
     * 实体服务对象
     *
     * @type {EAMPlanService}
     * @memberof GRID_001GridBase
     */
    public appEntityService: EAMPlanService = new EAMPlanService({ $store: this.$store });

    /**
     * 应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof GRID_001GridBase
     */
    protected appDeName: string = 'eamplan';

    /**
     * 应用实体中文名称
     *
     * @protected
     * @type {string}
     * @memberof GRID_001GridBase
     */
    protected appDeLogicName: string = '维护计划';

    /**
     * 界面UI服务对象
     *
     * @type {EAMPlanUIService}
     * @memberof GRID_001Base
     */  
    public appUIService:EAMPlanUIService = new EAMPlanUIService(this.$store);

    /**
     * 界面行为模型
     *
     * @type {*}
     * @memberof GRID_001Base
     */  
    public ActionModel: any = {
    };

    /**
     * 本地缓存标识
     *
     * @protected
     * @type {string}
     * @memberof GRID_001Base
     */
    protected localStorageTag: string = 'eamplan_grid_001_grid';

    /**
     * 所有列成员
     *
     * @type {any[]}
     * @memberof GRID_001GridBase
     */
    public allColumns: any[] = [
        {
            name: 'assetname',
            label: '资产',
            langtag: 'entities.eamplan.grid_001_grid.columns.assetname',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'plannumber',
            label: '计划编号',
            langtag: 'entities.eamplan.grid_001_grid.columns.plannumber',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'eamplanname',
            label: '维护计划名称',
            langtag: 'entities.eamplan.grid_001_grid.columns.eamplanname',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'eamlocationname',
            label: '功能位置',
            langtag: 'entities.eamplan.grid_001_grid.columns.eamlocationname',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
        {
            name: 'mdate',
            label: '制定日期',
            langtag: 'entities.eamplan.grid_001_grid.columns.mdate',
            show: true,
            util: 'PX',
            isEnableRowEdit: false,
        },
    ]

    /**
     * 获取表格行模型
     *
     * @type {*}
     * @memberof GRID_001GridBase
     */
    public getGridRowModel(){
        return {
          srfkey: new FormItemModel(),
        }
    }

    /**
     * 属性值规则
     *
     * @type {*}
     * @memberof GRID_001GridBase
     */
    public rules: any = {
        srfkey: [
            { required: false, validator: (rule:any, value:any, callback:any) => { return (rule.required && (value === null || value === undefined || value === "")) ? false : true;}, message: '维护计划标识 值不能为空', trigger: 'change' },
            { required: false, validator: (rule:any, value:any, callback:any) => { return (rule.required && (value === null || value === undefined || value === "")) ? false : true;}, message: '维护计划标识 值不能为空', trigger: 'blur' },
        ],
    }

    /**
     * 获取对应列class
     *
     * @type {*}
     * @memberof GRID_001Base
     */
    public hasRowEdit: any = {
        'assetname':false,
        'plannumber':false,
        'eamplanname':false,
        'eamlocationname':false,
        'mdate':false,
    };

    /**
     * 获取对应列class
     *
     * @param {*} $args row 行数据，column 列数据，rowIndex 行索引，列索引
     * @returns {void}
     * @memberof GRID_001Base
     */
    public getCellClassName(args: {row: any, column: any, rowIndex: number, columnIndex: number}): any {
        return ( this.hasRowEdit[args.column.property] && this.actualIsOpenEdit ) ? "edit-cell" : "info-cell";
    }


    /**
     * 导出数据格式化
     *
     * @param {*} filterVal
     * @param {*} jsonData
     * @param {any[]} [codelistColumns=[]]
     * @returns {Promise<any>}
     * @memberof GRID_001GridBase
     */
    public async formatExcelData(filterVal: any, jsonData: any, codelistColumns?: any[]): Promise<any> {
        return super.formatExcelData(filterVal, jsonData, [
        ]);
    }

}